from distutils.core import setup
setup(
  name = 'badWords_zh',
  packages = ['badWords_zh'],
  version = '1.1',
  description = 'Chinese Bad Word Counter',
  author = 'chhsu',
  author_email = 'dev@botimize.io',
  url = 'http://gitlab.botimize.io/chhsu/badWord_counter_zh',
  download_url = 'https://github.com/botimize/badWord_counter_zh/tarball/0.1',
  keywords = ['botimize', 'python', 'badWords', 'chinese', 'data_science'],
  classifiers = [],
)
